@@ -461,6 +461,7 @@ GVApi::onLogin1(bool success, const QByteArray &response, QNetworkReply *reply,
             break;
         }
 
+        Q_DEBUG("Starting service login");
         QUrl url(GV_ACCOUNT_SERVICELOGIN);
         success = postLogin (url, token);
     } while (0); // End cleanup block (not a loop)
@@ -598,7 +599,9 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
     QString strResponse = response;
     AsyncTaskToken *token = (AsyncTaskToken *)ctx;
     bool accountConfigured = true;
+    bool accountReviewRequested = false;
 
+    token->errorString.clear();
     do { // Begin cleanup block (not a loop)
         if (!success) break;
 
@@ -617,6 +620,13 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
                     success = false;
                     break;
                 }
+
+                if (dest.contains ("AccountRecoveryOptions")) {
+                    token->outParams["nextUrl"] = urlMoved;
+                    accountReviewRequested = true;
+                    success = false;
+                    break;
+                }
 #if 0
                 if (emitLog) {
                     Q_DEBUG("Moved to") << dest;
@@ -648,9 +658,17 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
         if (accountConfigured) {
             Q_WARN("Login failed.") << strResponse;
 
-            token->errorString = "User login failure";
+            if (token->errorString.isEmpty()) {
+                token->errorString = "User login failure";
+            }
             token->status = ATTS_LOGIN_FAILURE;
             token->emitCompleted ();
+        }
+        else if (accountReviewRequested) {
+            token->errorString = "User login failed: Account recovery "
+                                 "requested by Google";
+            token->status = ATTS_LOGIN_FAIL_SHOWURL;
+            token->emitCompleted ();
         } else {
             Q_WARN("Login failed because user account was not configured.");
 
@@ -1208,16 +1226,10 @@ GVApi::onGetInbox(bool success, const QByteArray &response,
         simpleReader.setContentHandler (&xmlHandler);
         simpleReader.setErrorHandler (&xmlHandler);
 
-        if (emitLog) {
-            Q_DEBUG("Begin parsing");
-        }
         if (!simpleReader.parse (&inputSource, false)) {
             Q_WARN("Failed to parse GV Inbox XML. Data =") << strReply;
             break;
         }
-        if (emitLog) {
-            Q_DEBUG("End parsing");
-        }
 
         qint32 msgCount = 0;
         if (!parseInboxJson (xmlHandler.strJson, xmlHandler.strHtml, msgCount))
@@ -1289,9 +1301,6 @@ GVApi::parseInboxJson(const QString &strJson, const QString &strHtml,
         }
 
         msgCount = scriptEngine.evaluate("msgList.length;").toInt32 ();
-        if (emitLog) {
-            Q_DEBUG("message count =") << msgCount;
-        }
 
         for (qint32 i = 0; i < msgCount; i++) {
             strTemp = QString(
