@@ -21,6 +21,7 @@ Contact: yuvraaj@gmail.com
 
 #include "GVWebPage.h"
 #include "GvXMLParser.h"
+#include "MyXmlErrorHandler.h"
 
 #define SYMBIAN_SIGNED 0
 
@@ -189,7 +190,7 @@ GVWebPage::login ()
     bool rv = connect (&webPage, SIGNAL (loadFinished (bool)),
                        this   , SLOT   (loginStage1 (bool)));
     Q_ASSERT(rv);
-    this->loadUrlString (GV_HTTPS);
+    this->loadUrlString (GOOGLE_SERVICELOGIN GV_SERVICELOGIN_PARAMS GV_HTTPS_M);
 
     rv = connect(&webPage, SIGNAL(loadProgress(int)),
                   this   , SLOT(loginProgress(int)));
@@ -220,8 +221,9 @@ GVWebPage::loginStage1 (bool bOk)
         if (bEmitLog) qDebug ("Login page loaded");
 
         QString strHtml = webPage.mainFrame()->toHtml();
-        if ((strHtml.contains ("Error 413")) ||
-            (strHtml.contains ("We've detected a problem with your cookie settings."))) {
+        if ((strHtml.contains("Error 413")) ||
+            (strHtml.contains("We've detected a problem with your cookie settings.")))
+        {
             strLastError = "Internal error. Login again";
             bOk = false;
             break;
@@ -460,8 +462,7 @@ GVWebPage::dialCallback (bool bCallback)
     }
 
     QMutexLocker locker(&mutex);
-    if (!bLoggedIn)
-    {
+    if (!bLoggedIn) {
         strLastError = "Not logged in. Cannot make calls.";
         completeCurrentWork (bCallback?GVAW_dialCallback:GVAW_dialOut, false);
         return (false);
@@ -1007,6 +1008,13 @@ GVWebPage::onGotInboxXML (QNetworkReply *reply)
         }
 
         QString strReply = reply->readAll ();
+
+        QRegExp rx(".TITLE.Moved.Temporarily..TITLE.");
+        if (strReply.contains (rx)) {
+            qWarning() << "Inbox location has MOVED!! Response = " << strReply;
+            break;
+        }
+
         QXmlInputSource inputSource;
         QXmlSimpleReader simpleReader;
         inputSource.setData (strReply);
@@ -1239,10 +1247,8 @@ GVWebPage::parseInboxJson(const QDateTime &dtUpdate, const QString &strJson,
                 resultSms = resultSms.trimmed ();
 
                 QString strSmsRow;
-                bool bSms = false;
                 if (!resultSms.isEmpty ()) {
                     result = "<div>" + resultSms + "</div>";
-                    bSms = true;
                 }
 
                 if ((parseMessageRow (result, strSmsRow)) &&
@@ -1670,38 +1676,6 @@ GVWebPage::startTimerForReply (QNetworkReply *reply)
     onSocketXfer (0,0);
 }//GVWebPage::startTimerForReply
 
-MyXmlErrorHandler::MyXmlErrorHandler(QObject *parent)
-: QAbstractMessageHandler(parent)
-{
-}//MyXmlErrorHandler::MyXmlErrorHandler
-
-void
-MyXmlErrorHandler::handleMessage (QtMsgType type, const QString &description,
-                                  const QUrl & /*identifier*/,
-                                  const QSourceLocation &sourceLocation)
-{
-    QString msg = QString("XML message: %1, at uri= %2 "
-                          "line %3 column %4")
-                .arg(description)
-                .arg(sourceLocation.uri ().toString ())
-                .arg(sourceLocation.line ())
-                .arg(sourceLocation.column ());
-
-    switch (type)
-    {
-    case QtDebugMsg:
-        qDebug() << msg;
-        break;
-    case QtWarningMsg:
-        qWarning() << msg;
-        break;
-    case QtCriticalMsg:
-    case QtFatalMsg:
-        qCritical() << msg;
-        break;
-    }
-}//MyXmlErrorHandler::handleMessage
-
 bool
 GVWebPage::markAsRead ()
 {
