@@ -317,6 +317,21 @@ OsDependent::getMainQML ()
     "Main.qml";
 }//OsDependent::getMainQML
 
+void
+OsDependent::getMultipliers(double &hMul, double &wMul, double &fontMul)
+{
+    hMul = wMul = fontMul = 1.0;
+#if DESKTOP_OS
+    fontMul = 1.5;
+#elif defined(Q_WS_MAEMO_5)
+    hMul = wMul = fontMul = 2;
+#elif defined(MEEGO_HARMATTAN)
+    hMul = wMul = fontMul = 2;
+#elif defined(Q_OS_SYMBIAN)
+    hMul = wMul = 1.5;
+#endif
+}//OsDependent::getMultipliers
+
 bool
 OsDependent::cipher(const QByteArray &byIn, QByteArray &byOut, bool bEncrypt)
 {
